==> pyskroutz-0.1.5-py3-none-any.whl: pyskroutz/models/categories.py <==
from pydantic import BaseModel
from typing import List, Optional

from ..models.base import (
    MetaItemBase,
    ItemBase,
    WebUriBaseItem,
    HttpUrl,
)


class GroupItem(BaseModel):
    """

    Attributes:
        id:
        name:
        order:
    """

    id: int
    name: str
    order: int


class GroupList(BaseModel):
    groups: GroupItem


class SpecificationItem(BaseModel):
    """Specification base model

    Attributes:
        id:
        name:
        values:
        order:
        unit:
    """

    id: int
    name: str
    values: List
    order: int
    unit: str


class SpecificationList(BaseModel):
    groups: Optional[List[GroupItem]]
    specifications: List[SpecificationItem]


class CategoryItem(ItemBase, WebUriBaseItem):
    """Category Item response model.

    Attributes:
        children_count:
        image_url:
        parent_id:
        fashion:
        layout_mode:
        code:
        path:
        show_specifications:
        manufacturer_title:
    """

    children_count: int
    image_url: HttpUrl
    parent_id: int
    fashion: bool
    layout_mode: str
    code: str
    path: str
    show_specifications: bool
    manufacturer_title: str


class CategoryList(BaseModel):
    """Response for a list of categories with meta details.

    Attributes:
        categories: A list of categories items.
        meta: response meta details.
    """

    categories: List[CategoryItem]
    meta: MetaItemBase


class CategoryRetrieve(BaseModel):
    category: CategoryItem

==> pyskroutz-0.1.7-py3-none-any.whl: pyskroutz/models/categories.py <==
"""Response models for category resources
"""
from pydantic import BaseModel
from typing import List, Optional

from ..models.base import (
    MetaItemBase,
    ItemBase,
    WebUriBaseItem,
    HttpUrl,
)


class GroupItem(BaseModel):
    """

    Attributes:
        id:
        name:
        order:
    """

    id: int
    name: str
    order: int


class GroupList(BaseModel):
    groups: GroupItem


class SpecificationItem(BaseModel):
    """Specification base model

    Attributes:
        id:
        name:
        values:
        order:
        unit:
    """

    id: int
    name: str
    values: List
    order: int
    unit: str


class SpecificationList(BaseModel):
    groups: Optional[List[GroupItem]]
    specifications: Optional[List[SpecificationItem]]


class CategoryItem(ItemBase, WebUriBaseItem):
    """Category Item response model.

    Attributes:
        children_count:
        image_url:
        parent_id:
        fashion:
        layout_mode:
        code:
        path:
        show_specifications:
        manufacturer_title:
    """

    children_count: int
    image_url: HttpUrl
    parent_id: int
    fashion: bool
    layout_mode: str
    code: str
    path: str
    show_specifications: bool
    manufacturer_title: str


class CategoryList(BaseModel):
    """Response for a list of categories with meta details.

    Attributes:
        categories: A list of categories items.
        meta: response meta details.
    """

    categories: List[CategoryItem]
    meta: MetaItemBase


class CategoryRetrieve(BaseModel):
    category: CategoryItem
